==> npm-font-open-sans-1.0.0.tgz: package/README.md <==
[![github tag][github-tag-image]][github-tag-url]
[![npm version][npm-version-image]][npm-version-url]
[![npm downloads][npm-downloads-image]][npm-downloads-url]
[![License][license-image]][license-url]

***

# npm package of Open Pro

Open Sans is a humanist sans serif typeface designed by Steve Matteson.


## Installation

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i npm-font-open-sans --save
```


## Usage

This a sample for usage in a LESS file:

```
@import '../../../node_modules/npm-font-open-sans/open-sans';
@FontPathOpenSans: "../fonts/open-sans";
```

First import the LESS file of the font and after this overwrite the default path. That's it ...



## Source of font files

[Open Sans at FontFaceKit](https://github.com/FontFaceKit/open-sans)


## License

Fonts: Licensed under [Apache 2.0](https://github.com/dasrick/npm-font-open-sans/blob/master/LICENSE)

***

[github-tag-image]: https://img.shields.io/github/tag/dasrick/npm-font-open-sans.svg?style=flat-square
[github-tag-url]: https://github.com/dasrick/npm-font-open-sans

[npm-version-image]: https://img.shields.io/npm/v/npm-font-open-sans.svg?style=flat-square
[npm-version-url]: https://www.npmjs.com/package/npm-font-open-sans
[npm-downloads-image]: https://img.shields.io/npm/dm/npm-font-open-sans.svg?style=flat-square
[npm-downloads-url]: https://www.npmjs.com/package/npm-font-open-sans

[license-image]: https://img.shields.io/github/license/dasrick/npm-font-open-sans.svg?style=flat-square
[license-url]: https://github.com/dasrick/npm-font-open-sans/blob/master/LICENSE

==> npm-font-open-sans-1.0.1.tgz: package/README.md <==
[![github tag][github-tag-image]][github-tag-url]
[![npm version][npm-version-image]][npm-version-url]
[![npm downloads][npm-downloads-image]][npm-downloads-url]
[![License][license-image]][license-url]

***

# npm package of Open Sans

Open Sans is a humanist sans serif typeface designed by Steve Matteson.


## Installation

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i npm-font-open-sans --save
```


## Usage

This a sample for usage in a LESS file:

```
@import '../../../node_modules/npm-font-open-sans/open-sans';
@FontPathOpenSans: "../fonts/open-sans";
```

First import the LESS file of the font and after this overwrite the default path. That's it ...



## Source of font files

[Open Sans at FontFaceKit](https://github.com/FontFaceKit/open-sans)


## License

Fonts: Licensed under [Apache 2.0](https://github.com/dasrick/npm-font-open-sans/blob/master/LICENSE)

***

[github-tag-image]: https://img.shields.io/github/tag/dasrick/npm-font-open-sans.svg?style=flat-square
[github-tag-url]: https://github.com/dasrick/npm-font-open-sans

[npm-version-image]: https://img.shields.io/npm/v/npm-font-open-sans.svg?style=flat-square
[npm-version-url]: https://www.npmjs.com/package/npm-font-open-sans
[npm-downloads-image]: https://img.shields.io/npm/dm/npm-font-open-sans.svg?style=flat-square
[npm-downloads-url]: https://www.npmjs.com/package/npm-font-open-sans

[license-image]: https://img.shields.io/github/license/dasrick/npm-font-open-sans.svg?style=flat-square
[license-url]: https://github.com/dasrick/npm-font-open-sans/blob/master/LICENSE
